require(untb, quietly=TRUE, save=FALSE)

"saunders" <- 
structure(list(exposed = c(TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
TRUE, TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
FALSE, FALSE, FALSE, FALSE), Ophiactis.resiliens = c(13, 16, 
4, 2, 9, 3, 7, 1, 6, 1, 3, 13, 4, 19, 20, 1, 0, 0, 1, 3, 12, 
19, 2, 6, 3, 3, 1, 1, 0, 8, 0, 0, 0, 0, 0, 3, 1, 2, 0, 0), Ophiopteris.antipodum = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Asterina.regularis = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Evechinus.chloroticus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Stichopus.juvenile. = c(0, 
4, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 3, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Ocnus.calcarea = c(0, 
0, 1, 3, 1, 0, 1, 0, 2, 2, 0, 0, 0, 0, 1, 0, 0, 0, 14, 2, 0, 
5, 0, 0, 0, 0, 0, 4, 1, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0), Onithochiton = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Acanthochitona.zelandica = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0), Aclis.sp..or.Seila.sp. = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0), Anabathron.angulatus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Astraea.heliotropium = c(0, 
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Austromitra.rubiginosa = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Melanella.sp. = c(0, 
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Buccinulum.lineum.lineum = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Buccinulum.robustum = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Buccinulum.sp = c(0, 
0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Cantharidus.purpureus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1), Crassitoniella.carinata = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Maoricrypta.monoxyla = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0), Diloma.bicanaliculata = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Eatoniella.albocolumella = c(0, 
0, 0, 0, 0, 0, 2, 0, 1, 1, 6, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Eatoniella.mortoni = c(0, 
0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Eatoniella.olivacea = c(1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Eatoniella.roseocincta = c(1, 
0, 1, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 2, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Eatoniella.sp. = c(1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Fictonoba.carnosa.carnosa = c(0, 
0, 0, 2, 0, 0, 0, 0, 0, 0, 4, 0, 2, 1, 24, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Lamellaria.ophione = c(0, 
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Macrozafra.subabnormis = c(1, 
0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Merelina.taupoensis = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Micrelenchus.sanguineus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Muricopsis.octagonus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 
0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Paxula.paxillus = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Pisinna.manawatawhia = c(0, 
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Pisinna.olivacea.impressa = c(0, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 
1, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Pisinna.rekohuana = c(1, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 3, 1, 10, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Prolixodens.infracolor = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Rissoina..chathamensis = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Sagenotriphora.ampulla = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Seila.cincta = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Sigapatella.novaezelandiae = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Taron.dubius = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Trochus.viridis = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0), Tugali.suteri = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Turbo.smaragdas = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0), Xymene.traversi = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0), Zalipais.lissa = c(0, 
0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Zemitrella.choava = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Zemitrella.pseudomarginata = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Chemnitzia.sp = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0), Linopyrga.rugata = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Aplysia..Varria..dactylomela = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Aphelodoris.luctuosa = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Dendrodoris.citrina = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Tritonia.flemingi = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Okenia.plana = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0), Borniola.reniformis = c(3, 
0, 1, 1, 2, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1, 0, 0, 0, 1, 0, 3, 0, 
0, 0, 0, 3, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Cardita.brookesi = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Chlamys.zelandiae = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Felaniella..Zemysia..zelandica = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Hiatella.arctica = c(3, 
3, 0, 0, 9, 1, 7, 0, 0, 0, 0, 0, 1, 9, 4, 2, 0, 1, 1, 6, 0, 0, 
1, 2, 0, 3, 10, 6, 2, 3, 0, 0, 0, 2, 0, 0, 0, 0, 2, 0), Nuculidae = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Trichomusculus.barbatus = c(7, 
5, 0, 2, 6, 4, 2, 1, 1, 2, 11, 7, 4, 2, 9, 1, 0, 0, 1, 0, 1, 
7, 1, 2, 0, 3, 1, 1, 3, 1, 0, 1, 0, 1, 1, 0, 0, 0, 1, 0), Ostracoda = c(2, 
0, 0, 2, 2, 0, 1, 0, 0, 0, 0, 0, 0, 1, 17, 0, 0, 0, 0, 0, 0, 
2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Harpacticoid.copepods = c(0, 
0, 2, 0, 1, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 1, 0, 0, 0, 0, 3, 
0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Balanus.sp. = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 5, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Cumaceans = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0), Mysids = c(0, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Tanaid.1...Leptocheila = c(12, 
5, 4, 2, 5, 12, 1, 0, 1, 2, 10, 4, 18, 4, 1, 1, 2, 2, 9, 2, 5, 
3, 7, 9, 5, 1, 11, 7, 1, 12, 10, 17, 7, 13, 9, 2, 0, 5, 3, 0), 
    Tanaid.2 = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0), Tanaid.3...Synapseudes = c(12, 6, 17, 
    3, 7, 1, 1, 0, 1, 0, 6, 1, 2, 0, 12, 0, 0, 0, 0, 1, 1, 1, 
    0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Anatanais = c(4, 
    0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 5, 7, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Gnathia.sp. = c(0, 0, 0, 2, 2, 0, 0, 0, 1, 0, 7, 3, 0, 
    4, 0, 1, 0, 0, 2, 1, 6, 2, 0, 0, 3, 1, 4, 8, 2, 0, 0, 3, 
    1, 0, 1, 0, 0, 3, 0, 0), Colanthura = c(0, 0, 0, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Paranthura = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 
    0), Cyathura = c(0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 2, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0), Cirolanidae = c(0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0), Limnoriidae = c(16, 
    1, 6, 12, 4, 0, 7, 0, 1, 3, 10, 2, 0, 5, 5, 11, 1, 3, 9, 
    2, 3, 1, 0, 9, 0, 11, 46, 6, 22, 4, 0, 4, 0, 4, 3, 0, 0, 
    11, 0, 12), Plakarthrium.typicum = c(1, 1, 3, 14, 6, 6, 2, 
    2, 12, 5, 1, 1, 1, 3, 1, 3, 0, 3, 4, 7, 1, 0, 5, 8, 14, 0, 
    8, 4, 0, 3, 1, 1, 0, 0, 1, 0, 0, 0, 0, 0), Cymodocella.capra = c(2, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 4, 1, 1, 3, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Dynamenoides.decima = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Dynamenopsis.varicolor = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 6, 4, 19, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Cassidinopsis.admirabilis = c(1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Asellota.sp.2 = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Janiridae = c(3, 4, 1, 0, 0, 0, 4, 0, 0, 0, 1, 3, 2, 
    1, 0, 1, 0, 1, 6, 5, 4, 6, 2, 2, 6, 5, 7, 13, 3, 6, 0, 2, 
    1, 2, 0, 3, 1, 4, 21, 3), Joeropsididae = c(8, 3, 4, 2, 4, 
    1, 3, 0, 1, 0, 0, 3, 2, 0, 5, 1, 0, 1, 2, 2, 0, 4, 0, 0, 
    0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0), Munnidae = c(0, 
    0, 5, 0, 2, 1, 1, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, 0, 0, 1, 
    1, 4, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Neastacilla.falclandica = c(7, 0, 3, 4, 8, 3, 7, 0, 1, 
    0, 0, 1, 0, 8, 0, 0, 1, 1, 1, 0, 3, 0, 0, 4, 1, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Caprella.equilibra = c(5, 
    0, 3, 10, 21, 0, 4, 0, 0, 0, 6, 4, 9, 0, 1, 1, 2, 0, 5, 16, 
    1, 2, 0, 4, 11, 0, 2, 9, 10, 8, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0), Polycheria.obtusa = c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 
    0, 0, 0, 0, 0, 0, 3, 1, 0, 0), Amphilochus.sp. = c(0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    1, 1, 0, 3, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
    Gitanopsis.sp. = c(2, 0, 1, 0, 14, 1, 2, 0, 0, 0, 0, 0, 2, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0), Ampithoe = c(7, 0, 1, 0, 0, 0, 0, 
    0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 3, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Ceina.sp = c(0, 
    0, 1, 0, 1, 1, 0, 0, 0, 0, 2, 1, 4, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Colomastix.subcastellata = c(0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0), Corophiidae = c(74, 
    22, 30, 5, 14, 0, 3, 0, 0, 2, 6, 0, 8, 11, 17, 5, 0, 0, 1, 
    3, 0, 5, 0, 0, 3, 0, 1, 0, 0, 15, 0, 0, 0, 0, 2, 0, 0, 0, 
    0, 0), Aora.Aoroides = c(0, 1, 16, 10, 3, 0, 2, 0, 2, 1, 
    13, 1, 2, 5, 8, 0, 1, 0, 2, 1, 0, 0, 1, 0, 8, 3, 0, 1, 1, 
    3, 1, 0, 0, 2, 3, 0, 1, 1, 0, 0), Corophium.acutum = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Gammaropsis.sp. = c(28, 25, 85, 26, 160, 42, 15, 0, 5, 
    7, 39, 14, 84, 32, 45, 12, 3, 0, 8, 13, 9, 68, 6, 2, 61, 
    15, 1, 2, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0), Gammaropsis.tawahi = c(0, 
    7, 0, 3, 4, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Paracorophium.excavatum = c(2, 1, 26, 12, 12, 1, 2, 1, 
    0, 1, 56, 3, 47, 26, 3, 20, 0, 0, 0, 5, 0, 0, 0, 0, 1, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0), Ericthonius.brasiliensis = c(1, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    3, 3, 0, 0, 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Ericthonius.sp = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0), Microdeutopus.apopo = c(0, 0, 
    0, 1, 0, 0, 0, 0, 1, 0, 5, 0, 1, 0, 16, 0, 0, 0, 0, 2, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
    Neocyproidea.sp. = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0), Atylus.sp = c(0, 0, 0, 0, 0, 
    1, 1, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0), Atylus.taupo = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 
    0), Paradexamine = c(1, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 0, 
    1, 0, 1, 0, 0, 0, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 1, 0, 1, 0), Bircenna.fulva = c(0, 0, 0, 0, 
    5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Oradarea.novaezelandiae = c(5, 
    0, 8, 1, 1, 3, 2, 4, 0, 0, 1, 0, 0, 0, 0, 1, 2, 2, 11, 1, 
    0, 0, 1, 3, 4, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 2, 2, 
    0), Eusiridae = c(4, 6, 4, 0, 3, 20, 33, 4, 11, 3, 22, 2, 
    6, 6, 2, 2, 4, 6, 10, 3, 4, 14, 1, 0, 10, 3, 2, 13, 2, 3, 
    1, 0, 0, 0, 0, 2, 7, 16, 8, 3), Maera.incerta = c(3, 0, 5, 
    0, 9, 2, 3, 0, 0, 0, 1, 0, 4, 0, 4, 0, 0, 0, 0, 0, 2, 3, 
    0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Metaceradocus.whakatane = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 5, 0, 1, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Melita.festiva = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 1, 0, 0, 2, 0), Parapherusa.crassipes = c(0, 
    0, 4, 4, 2, 1, 1, 0, 0, 0, 7, 0, 15, 7, 3, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Hyale.sp. = c(0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 0, 0, 2, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0), Panoploea.spinosa = c(0, 0, 0, 0, 
    0, 0, 5, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 4, 1, 0, 2, 0, 
    3, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0), Ischyrocerus = c(20, 
    0, 3, 1, 9, 2, 1, 0, 0, 1, 3, 1, 4, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Ventojassa = c(278, 3, 167, 36, 115, 17, 20, 0, 8, 7, 
    63, 20, 135, 65, 30, 45, 1, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0), Leucothoe.trailli = c(1, 
    0, 0, 0, 0, 1, 1, 0, 0, 0, 3, 1, 0, 2, 0, 0, 16, 10, 3, 2, 
    1, 1, 1, 1, 3, 0, 2, 8, 5, 1, 2, 4, 0, 0, 0, 0, 9, 7, 12, 
    0), Liljeborgia.akaroica = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 2, 3, 0, 0, 5, 2, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Lys..sp..1..Ambasia.sp. = c(1, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 
    0), Lys..sp..2 = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0), Stomacontion.hurleyi = c(1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, 2, 
    0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Nihotunga.ilika = c(0, 
    0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Iphinotus.typicus = c(0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Brolginae = c(0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0), Podocerus.karu = c(6, 
    3, 10, 8, 7, 2, 8, 1, 0, 2, 2, 11, 11, 17, 14, 9, 2, 1, 0, 
    3, 1, 8, 1, 6, 25, 1, 3, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0), Seba.typica = c(1, 6, 1, 1, 0, 0, 1, 0, 0, 0, 2, 0, 
    0, 3, 6, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 2, 4, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0), Tetradeion.crassum. = c(0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
    Stenothoe.sp. = c(17, 2, 1, 9, 22, 3, 2, 0, 3, 0, 3, 1, 11, 
    2, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0), Alpheus.socialis = c(0, 2, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 
    0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Pagurus.sp...Hermit.crabs. = c(1, 
    1, 0, 0, 0, 0, 1, 3, 0, 1, 5, 3, 6, 0, 0, 5, 0, 1, 0, 0, 
    1, 2, 4, 1, 12, 1, 3, 0, 21, 0, 0, 0, 0, 0, 0, 0, 3, 1, 0, 
    1), Petrolisthes.novaezelandiae = c(11, 13, 20, 3, 17, 10, 
    18, 2, 0, 7, 27, 11, 6, 4, 18, 17, 6, 2, 43, 33, 7, 27, 14, 
    5, 11, 7, 31, 9, 26, 8, 7, 8, 0, 8, 5, 0, 1, 2, 2, 1), Halicarcinus.ovatus = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Notomithrax.minor = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Leptomithrax.garricki = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Pilumnus.novaezelandiae = c(0, 0, 0, 0, 1, 0, 0, 0, 0, 
    1, 1, 1, 2, 0, 0, 0, 0, 1, 3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Halacaridae = c(0, 0, 
    0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
    Pycnogonida = c(1, 0, 0, 2, 0, 5, 2, 5, 0, 3, 8, 2, 2, 1, 
    3, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 2, 3, 2, 
    0, 0, 0, 0, 0, 0, 0), Acrocirridae = c(0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    1, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Ampharetiidae = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 
    0), Capitellidae = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 3, 0, 0), Chaetopteridae = c(0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 
    0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Chrysopatellidae = c(0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, 1, 0, 0, 0, 1, 0, 
    1, 3, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Cirratulidae = c(2, 3, 0, 0, 1, 0, 0, 0, 0, 0, 2, 0, 
    2, 1, 2, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 5, 3, 1, 0, 0, 
    0, 0, 1, 0, 0, 0, 0, 0, 0), Eunicidae = c(0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Dorvillea = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Eunice = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 10, 0, 0, 1, 1, 0, 2, 0, 
    0, 0, 0, 0, 1, 0, 0), Lysidice = c(0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0), Pherusa.parmata = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
    0), Glyceridae = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0), Lumbrinereidae = c(0, 0, 0, 0, 0, 
    0, 2, 0, 0, 0, 5, 1, 4, 2, 0, 0, 0, 0, 2, 0, 2, 0, 0, 2, 
    0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Maldanidae = c(0, 
    0, 0, 0, 0, 0, 6, 0, 0, 0, 1, 0, 4, 1, 4, 0, 0, 0, 1, 0, 
    0, 2, 1, 0, 0, 15, 7, 0, 1, 0, 2, 0, 0, 1, 0, 1, 5, 2, 0, 
    0), Nereididae = c(6, 5, 9, 5, 14, 13, 16, 8, 9, 5, 17, 4, 
    13, 18, 6, 5, 3, 3, 7, 7, 0, 8, 7, 1, 4, 9, 19, 25, 13, 18, 
    3, 5, 0, 3, 1, 1, 0, 2, 1, 1), Protoaricia. = c(4, 3, 5, 
    3, 5, 4, 15, 1, 3, 0, 25, 3, 5, 4, 29, 0, 0, 0, 2, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 1, 20, 1, 3, 1, 2, 0, 0, 0, 1, 0, 0), 
    Armandia = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 0, 4, 
    0, 0, 0, 0, 0, 0, 3, 0, 0, 1, 0, 0, 0, 0, 1, 0, 4, 0, 1, 
    0, 0, 0, 0, 1, 0), Phyllodocidae = c(0, 2, 0, 0, 1, 1, 1, 
    0, 1, 0, 7, 0, 1, 2, 2, 0, 1, 0, 0, 2, 2, 0, 1, 0, 1, 2, 
    1, 2, 3, 8, 1, 0, 0, 0, 0, 1, 0, 3, 1, 1), Polynoidae = c(0, 
    4, 1, 1, 1, 0, 5, 0, 1, 0, 4, 1, 1, 2, 3, 0, 0, 0, 0, 0, 
    0, 6, 0, 1, 0, 2, 4, 5, 0, 5, 2, 0, 0, 3, 0, 0, 1, 2, 0, 
    0), Sabellariidae = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0), Sabellidae = c(4, 11, 3, 0, 5, 
    1, 0, 0, 0, 0, 3, 2, 6, 4, 6, 2, 2, 0, 1, 1, 6, 5, 6, 1, 
    9, 9, 12, 1, 2, 10, 0, 0, 0, 14, 6, 0, 0, 2, 0, 0), Idyanthyrsus.sp. = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 
    0), Scalibregmidae..Hyboscolex. = c(0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 1, 3, 0, 0, 1, 1, 
    0, 1, 2, 3, 2, 1, 0, 1, 1, 0, 0, 0, 1, 0), Serpulidae = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 1, 0, 
    0), Spirorbinae = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 0), Spionidae = c(0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 11, 3, 10, 0, 4, 3, 0, 1, 1, 3, 0, 0, 0, 0, 0, 
    1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Spionidae...Boccardia = c(3, 
    14, 3, 0, 3, 0, 1, 0, 1, 0, 4, 2, 0, 3, 0, 0, 1, 0, 1, 0, 
    2, 2, 2, 10, 1, 1, 1, 1, 6, 0, 0, 1, 0, 2, 2, 0, 3, 4, 1, 
    0), Syllinae = c(20, 27, 7, 4, 13, 9, 13, 6, 9, 5, 50, 27, 
    16, 16, 26, 6, 4, 3, 12, 10, 2, 9, 3, 6, 3, 27, 32, 32, 3, 
    8, 0, 2, 1, 0, 0, 2, 0, 1, 0, 2), Trypanosyllis = c(0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 2, 5, 0, 0, 0, 1, 0, 2, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
    Eusyllinae = c(5, 6, 7, 2, 9, 11, 13, 3, 5, 4, 13, 10, 3, 
    10, 11, 3, 1, 0, 6, 13, 1, 7, 2, 1, 1, 2, 2, 6, 7, 17, 0, 
    1, 0, 2, 1, 0, 0, 0, 5, 0), Exogoninae = c(27, 12, 11, 10, 
    20, 19, 15, 1, 9, 4, 25, 11, 18, 13, 30, 15, 2, 2, 10, 28, 
    13, 30, 10, 9, 8, 11, 3, 15, 8, 17, 2, 1, 1, 1, 1, 2, 4, 
    9, 8, 0), Terebellidae = c(0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 1, 0, 0, 7, 0, 4, 1, 0, 
    7, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0), Nemerteans = c(5, 5, 4, 
    2, 3, 2, 3, 0, 1, 0, 26, 5, 3, 6, 7, 1, 0, 0, 4, 5, 2, 1, 
    0, 2, 1, 0, 1, 2, 1, 5, 0, 1, 0, 1, 0, 0, 1, 3, 0, 0), Nematodes = c(24, 
    27, 3, 2, 13, 4, 8, 0, 7, 1, 6, 6, 6, 11, 12, 1, 2, 2, 2, 
    31, 1, 7, 13, 7, 1, 4, 7, 30, 3, 14, 1, 2, 0, 0, 0, 1, 1, 
    0, 8, 0), Flatworm...Robust..entire.edge = c(0, 0, 0, 2, 
    9, 1, 0, 0, 0, 0, 3, 1, 1, 5, 10, 1, 0, 0, 0, 0, 0, 1, 0, 
    0, 0, 2, 1, 3, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), Platyhelminthes.4 = c(0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0), Sipunculid = c(0, 1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
    0, 1, 0, 0, 0, 0, 0, 0)), .Names = c("exposed", "Ophiactis.resiliens", 
"Ophiopteris.antipodum", "Asterina.regularis", "Evechinus.chloroticus", 
"Stichopus.juvenile.", "Ocnus.calcarea", "Onithochiton", "Acanthochitona.zelandica", 
"Aclis.sp..or.Seila.sp.", "Anabathron.angulatus", "Astraea.heliotropium", 
"Austromitra.rubiginosa", "Melanella.sp.", "Buccinulum.lineum.lineum", 
"Buccinulum.robustum", "Buccinulum.sp", "Cantharidus.purpureus", 
"Crassitoniella.carinata", "Maoricrypta.monoxyla", "Diloma.bicanaliculata", 
"Eatoniella.albocolumella", "Eatoniella.mortoni", "Eatoniella.olivacea", 
"Eatoniella.roseocincta", "Eatoniella.sp.", "Fictonoba.carnosa.carnosa", 
"Lamellaria.ophione", "Macrozafra.subabnormis", "Merelina.taupoensis", 
"Micrelenchus.sanguineus", "Muricopsis.octagonus", "Paxula.paxillus", 
"Pisinna.manawatawhia", "Pisinna.olivacea.impressa", "Pisinna.rekohuana", 
"Prolixodens.infracolor", "Rissoina..chathamensis", "Sagenotriphora.ampulla", 
"Seila.cincta", "Sigapatella.novaezelandiae", "Taron.dubius", 
"Trochus.viridis", "Tugali.suteri", "Turbo.smaragdas", "Xymene.traversi", 
"Zalipais.lissa", "Zemitrella.choava", "Zemitrella.pseudomarginata", 
"Chemnitzia.sp", "Linopyrga.rugata", "Aplysia..Varria..dactylomela", 
"Aphelodoris.luctuosa", "Dendrodoris.citrina", "Tritonia.flemingi", 
"Okenia.plana", "Borniola.reniformis", "Cardita.brookesi", "Chlamys.zelandiae", 
"Felaniella..Zemysia..zelandica", "Hiatella.arctica", "Nuculidae", 
"Trichomusculus.barbatus", "Ostracoda", "Harpacticoid.copepods", 
"Balanus.sp.", "Cumaceans", "Mysids", "Tanaid.1...Leptocheila", 
"Tanaid.2", "Tanaid.3...Synapseudes", "Anatanais", "Gnathia.sp.", 
"Colanthura", "Paranthura", "Cyathura", "Cirolanidae", "Limnoriidae", 
"Plakarthrium.typicum", "Cymodocella.capra", "Dynamenoides.decima", 
"Dynamenopsis.varicolor", "Cassidinopsis.admirabilis", "Asellota.sp.2", 
"Janiridae", "Joeropsididae", "Munnidae", "Neastacilla.falclandica", 
"Caprella.equilibra", "Polycheria.obtusa", "Amphilochus.sp.", 
"Gitanopsis.sp.", "Ampithoe", "Ceina.sp", "Colomastix.subcastellata", 
"Corophiidae", "Aora.Aoroides", "Corophium.acutum", "Gammaropsis.sp.", 
"Gammaropsis.tawahi", "Paracorophium.excavatum", "Ericthonius.brasiliensis", 
"Ericthonius.sp", "Microdeutopus.apopo", "Neocyproidea.sp.", 
"Atylus.sp", "Atylus.taupo", "Paradexamine", "Bircenna.fulva", 
"Oradarea.novaezelandiae", "Eusiridae", "Maera.incerta", "Metaceradocus.whakatane", 
"Melita.festiva", "Parapherusa.crassipes", "Hyale.sp.", "Panoploea.spinosa", 
"Ischyrocerus", "Ventojassa", "Leucothoe.trailli", "Liljeborgia.akaroica", 
"Lys..sp..1..Ambasia.sp.", "Lys..sp..2", "Stomacontion.hurleyi", 
"Nihotunga.ilika", "Iphinotus.typicus", "Brolginae", "Podocerus.karu", 
"Seba.typica", "Tetradeion.crassum.", "Stenothoe.sp.", "Alpheus.socialis", 
"Pagurus.sp...Hermit.crabs.", "Petrolisthes.novaezelandiae", 
"Halicarcinus.ovatus", "Notomithrax.minor", "Leptomithrax.garricki", 
"Pilumnus.novaezelandiae", "Halacaridae", "Pycnogonida", "Acrocirridae", 
"Ampharetiidae", "Capitellidae", "Chaetopteridae", "Chrysopatellidae", 
"Cirratulidae", "Eunicidae", "Dorvillea", "Eunice", "Lysidice", 
"Pherusa.parmata", "Glyceridae", "Lumbrinereidae", "Maldanidae", 
"Nereididae", "Protoaricia.", "Armandia", "Phyllodocidae", "Polynoidae", 
"Sabellariidae", "Sabellidae", "Idyanthyrsus.sp.", "Scalibregmidae..Hyboscolex.", 
"Serpulidae", "Spirorbinae", "Spionidae", "Spionidae...Boccardia", 
"Syllinae", "Trypanosyllis", "Eusyllinae", "Exogoninae", "Terebellidae", 
"Nemerteans", "Nematodes", "Flatworm...Robust..entire.edge", 
"Platyhelminthes.4", "Sipunculid"), row.names = c("1", "2", "3", 
"4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", 
"16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", 
"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", 
"38", "39", "40"), class = "data.frame")

jj <- t(saunders)[-1,]
jj.exposed <- saunders[,1]

"saunders.tot" <- count(apply(jj,1,sum))

"saunders.exposed"   <- jj[, jj.exposed]
"saunders.sheltered" <- jj[,!jj.exposed]

"saunders.exposed.tot"   <- count(apply(saunders.exposed,1,sum))
"saunders.sheltered.tot" <- count(apply(saunders.sheltered,1,sum))

rm(jj)
rm(jj.exposed)
